@@ -3,6 +3,8 @@
 ##################### Copyright 2013 Richard Kelsch #########################
 #####################      All Rights Reserved      #########################
 #############################################################################
+####### Licensing information available near the end of this file. ##########
+#############################################################################
 
 package Debug::Easy;
 
@@ -16,7 +18,7 @@ use Data::Dumper::Simple;
 BEGIN {
     require Exporter;
     # set the version for version checking
-    our $VERSION   = 0.03;
+    our $VERSION   = 0.04;
     # Inherit from Exporter to export functions and variables
     our @ISA       = qw(Exporter);
     # Functions and variables which are exported by default
@@ -33,133 +35,6 @@ my %ANSILevel = (); # Global debug level colorized messages hash.
 my $LOG = Log::Fast->global();
 my $MASTERSTART = time; # Script start timestamp.
 
-END { # We spit out one last message before we die, the total execute time.
-    my $bench = colored(['bright_cyan on_black'],sprintf('%06s',sprintf('%.02f',(time - $MASTERSTART))));
-    $LOG->DEBUG(' %s%s %s',$bench,$ANSILevel{'DEBUG'}, colored(['black on_white'],'---- Script complete ----'));
-}
-
-# This module uses the Log::Fast library heavily.  Many of the
-# Log::Fast variables and features can work here.
-sub new {
-    my $class = shift;
-
-    my $self = {
-		'LogLevel'           => 'ERR',       # Default is errors only
-		'Type'               => 'fh',
-		'Path'               => '/var/log',
-		'FileHandle'         => \*STDERR,
-		'MasterStart'        => $MASTERSTART, # Pull in the script start timestamp
-		'ERR_LastStamp'      => time,
-		'WARN_LastStamp'     => time,
-		'INFO_LastStamp'     => time,
-		'NOTICE_LastStamp'   => time,
-		'DEBUG_LastStamp'    => time,
-		'DEBUGMAX_LastStamp' => time,
-		'LOG'                => $LOG, # Pull in the global Log::Fast object.
-		'Color'              => 1,
-		'DateStamp'          => colored(['yellow on_black'],'%D'),
-		'TimeStamp'          => colored(['yellow on_black'],'%T'),
-		'Padding'            => -25,
-		'Prefix'             => '',
-		@_
-    };
-    # This instructs the ANSIColor library to turn off coloring,
-    # if the Color attribute is set to zero.
-    $ENV{'ANSI_COLORS_DISABLED'} = 1 if ($self->{'Color'} =~ /0|FALSE|OFF/i);
-
-    %ANSILevel = (
-		'ERR'       => colored(['white on_red'],       '[ ERROR ]'),
-		'WARN'      => colored(['black on_yellow'],    '[WARNING]'),
-		'NOTICE'    => colored(['black on_magenta'],   '[NOTICE ]'),
-		'INFO'      => colored(['white on_black'],     '[ INFO  ]'),
-		'DEBUG'     => colored(['bold green on_black'],'[ DEBUG ]'),
-		'DEBUGMAX'  => colored(['bold green on_black'],'[-DEBUG-]')
-    );
-    # This assembles the Time and Date stamping output.  If any of the
-    # variables are blank, then that part will be disabled.
-    $self->{'Prefix'} = $self->{'DateStamp'} . ' ' . $self->{'TimeStamp'};
-
-    # The Global loglevel is set here.
-    if ($self->{'LogLevel'} eq 'VERBOSE') {
-		$self->{'LOG'}->level('INFO');
-    } elsif ($self->{'LogLevel'} eq 'DEBUGMAX') {
-		$self->{'LOG'}->level('DEBUG');
-    } else {
-		$self->{'LOG'}->level( $self->{'LogLevel'} );
-    }
-
-    $self->{'LOG'}->config({
-							   'type'   => $self->{'Type'},
-							   'path'   => $self->{'Path'},
-							   'prefix' => $self->{'Prefix'},
-							   'fh'     => $self->{'FileHandle'}
-						   });
-    $self->{'LOG'}->DEBUG('   %.02f%s %s',0,$ANSILevel{'DEBUG'}, colored(['black on_white'],'----- Script begin -----'));
-    bless($self,$class);
-    return($self);
-}
-sub debug {
-    my $self  = shift;
-    my $cline = shift;
-    my $level = shift;
-    my $msgs  = shift;
-
-    my @messages;
-
-    if (ref($msgs) eq 'SCALAR') {
-		push(@messages,$msgs);
-    } elsif (ref($msgs) eq 'ARRAY') {
-		@messages = @{$msgs};
-    } else {
-		push(@messages,Dumper($msgs));
-    }
-
-    my ($package, $filename, $line, $subroutine, $hasargs, $wantarray, $evaltext, $is_require, $hints, $bitmask) = caller(1);
-    if (! defined($subroutine) || $subroutine eq '') {
-		$subroutine = 'main';
-    }
-    if (length($subroutine) > abs($self->{'Padding'})) {
-		$self->{'Padding'} = 0 - length($subroutine);
-    }
-    my $thisBench = sprintf('%7s',sprintf(' %.02f',time - $self->{$level . '_LastStamp'})) . $ANSILevel{$level} . '[' . colored(['bold cyan on_black'],sprintf('%' . $self->{'Padding'} . 's>%04d',$subroutine,$cline)) . ']';
-    my $nested = do { my $n=0; 1 while caller(2 + $n++); ' ' x $n };
-    foreach my $msg (@messages) {
-		if ($msg =~ /\n/s) {
-			my @message = split(/\n/,$msg);
-			foreach my $line (@message) {
-				if ($level eq 'INFO' && $self->{'LogLevel'} eq 'VERBOSE') {
-					$self->{'LOG'}->config({'prefix' => ''});
-					$self->{'LOG'}->$level($line);
-					$self->{'LOG'}->config({'prefix' => $self->{'Prefix'}});
-				} elsif ($level eq 'DEBUGMAX') {
-					if ($self->{'LogLevel'} eq 'DEBUGMAX') {
-						$self->{'LOG'}->DEBUG($thisBench . $nested . $line);
-					}
-				} else {
-					$self->{'LOG'}->$level($thisBench . $nested . $line);
-				}
-			}
-		} else {
-			if ($level eq 'INFO' && $self->{'LogLevel'} eq 'VERBOSE') {
-				$self->{'LOG'}->config({'prefix' => ''});
-				$self->{'LOG'}->INFO($msg);
-				$self->{'LOG'}->config({'prefix' => $self->{'Prefix'}});
-			} elsif ($level eq 'DEBUGMAX') {
-				if ($self->{'LogLevel'} eq 'DEBUGMAX') {
-					$self->{'LOG'}->DEBUG($thisBench . $nested . $msg);
-				}
-			} else {
-				$self->{'LOG'}->$level($thisBench . $nested . $msg);
-			}
-		}
-    }
-    $self->{$level . '_LastStamp'} = time;
-}
-
-1;
-
-__END__
-
 =head1 NAME
 
 Debug::Easy - A Handy Debugging Module
@@ -222,16 +97,36 @@ All of this fully controllable by the coder.
 
 It is essentially a smart wrapper on top of Log::Fast.
 
-=head1 PARAMETERS
+=head1 EXPORTED VARIABLES
 
-=head2 LogLevel [level]
+=head2 @Levels
+
+ A simple list of all the acceptable debug levels to pass to the {debug} method,
+ and the {new} method.
+
+=cut
+
+END { # We spit out one last message before we die, the total execute time.
+    my $bench = colored(['bright_cyan on_black'],sprintf('%06s',sprintf('%.02f',(time - $MASTERSTART))));
+    $LOG->DEBUG(' %s%s %s',$bench,$ANSILevel{'DEBUG'}, colored(['black on_white'],'---- Script complete ----'));
+}
+
+=head1 METHODS
+
+=head2 new
+
+The parameter names are case insensitive as of Version 0.04.
+
+=over 1
+
+=item B<LogLevel> [level]
 
 This adjusts the global log level of the Debug object.  It requires
 a string.
 
-=over 1
+=over 2
 
-=item B<ERROR> (default)
+=item B<ERR> (default)
 
 This level shows only error messages and all other messages are not
 shown.
@@ -268,90 +163,248 @@ This level shows all messages, including level 2 debugging messages.
 
 =back
 
-=head2 Color [boolean] (Not case sensitive)
+=item B<Color> [boolean] (Not case sensitive)
 
-=over 1
+=over 2
 
 =item B<0>, B<Off>, or B<False> (Off)
 
-This turns off colored output.  Everything is plain text only.
+ This turns off colored output.  Everything is plain text only.
 
 =item B<1>, B<On>, or B<True> (On - Default)
 
-This turns on colored output.  This makes it easier to spot all of
-the different types of messages throughout a sea of debug output.
-You can pipe the output to Less, and see color, by using it's
-switch "-r".
+ This turns on colored output.  This makes it easier to spot all of
+ the different types of messages throughout a sea of debug output.
+ You can pipe the output to Less, and see color, by using it's
+ switch "-r".
 
 =back
 
-=head2 TimeStamp [pattern]
+=item B<TimeStamp> [pattern]
 
 Make this an empty string to turn it off, otherwise:
 
-=over 1
+=over 2
 
 =item B<%T>
 
-Formats the timestamp as HH:MM:SS.  This is the default for the
-timestamp.
+ Formats the timestamp as HH:MM:SS.  This is the default for the
+ timestamp.
 
 =item B<%S>
 
-Formats the timestamp as seconds.milliseconds.  Normally not needed,
-as the benchmark is more helpful.
+ Formats the timestamp as seconds.milliseconds.  Normally not needed,
+ as the benchmark is more helpful.
 
 =item B<%T %S>
 
-Combines both of the above.  Normally this is just too much, but here
-if you really want it.
+ Combines both of the above.  Normally this is just too much, but here
+ if you really want it.
 
 =back
 
-=head2 DateStamp [pattern]
+=item B<DateStamp> [pattern]
 
 Make this an empty string to turn it off, otherwise:
 
-=over 1
+=over 2
 
 =item B<%D>
 
-Formats the datestamp as YYYY-MM-DD.  It is the default, and the only
-option.
+ Formats the datestamp as YYYY-MM-DD.  It is the default, and the only
+ option.
 
 =back
 
-=head2 B<Type>
+=item B<Type>
 
-Output type. Possible values are: 'fh' (output to any already open
-filehandle) and 'unix' (output to syslog using UNIX socket).
+ Output type. Possible values are: 'fh' (output to any already open
+ filehandle) and 'unix' (output to syslog using UNIX socket).
 
-=over 1
+=over 2
 
 =item B<fh>
 
-When set to 'fh', you have to also set {FileHandle} to any open filehandle
-(like "\*STDERR", which is the default).
+ When set to 'fh', you have to also set {FileHandle} to any open filehandle
+ (like "\*STDERR", which is the default).
 
 =item B<unix>
 
-When set to 'unix', you have to also set {FileHandle} to a path pointing to an
-existing unix socket (typically it's '/dev/log').
+ When set to 'unix', you have to also set {FileHandle} to a path pointing to an
+ existing unix socket (typically it's '/dev/log').
 
 =back
 
-=head2 FileHandle
+=item B<FileHandle>
 
  File handle to write log messages if {Type} set to 'fh' (which is the default).
 
  Syslog's UNIX socket path to write log messages if {Type} set to 'unix'.
 
-=head1 EXPORTED VARIABLES
+=back
 
-=head2 @Levels
+=cut
 
- A simple list of all the acceptable debug levels to pass to the {debug} method,
- and the {new} method.
+sub new {
+    # This module uses the Log::Fast library heavily.  Many of the
+    # Log::Fast variables and features can work here.
+    my $class = shift;
+
+    my $self = {
+		'LogLevel'           => 'ERR',       # Default is errors only
+		'Type'               => 'fh',
+		'Path'               => '/var/log',
+		'FileHandle'         => \*STDERR,
+		'MasterStart'        => $MASTERSTART, # Pull in the script start timestamp
+		'ERR_LastStamp'      => time,
+		'WARN_LastStamp'     => time,
+		'INFO_LastStamp'     => time,
+		'NOTICE_LastStamp'   => time,
+		'DEBUG_LastStamp'    => time,
+		'DEBUGMAX_LastStamp' => time,
+		'LOG'                => $LOG, # Pull in the global Log::Fast object.
+		'Color'              => 1,
+		'DateStamp'          => colored(['yellow on_black'],'%D'),
+		'TimeStamp'          => colored(['yellow on_black'],'%T'),
+		'Padding'            => -25,
+		'Prefix'             => '',
+		@_
+    };
+	my @Keys = (keys %{$self});
+	foreach my $Key (@Keys) {
+		my $upper = uc($Key);
+		if ($Key ne $upper) {
+			$self->{$upper} = $self->{$Key};
+			# This fixes a documentation error for past versions
+			$self->{$upper} = 'ERR' if ($upper eq 'LOGLEVEL' && $self->{$upper} =~ /^ERROR$/i);
+			delete($self->{$Key});
+		}
+	}
+    # This instructs the ANSIColor library to turn off coloring,
+    # if the Color attribute is set to zero.
+    $ENV{'ANSI_COLORS_DISABLED'} = 1 if ($self->{'COLOR'} =~ /0|FALSE|OFF/i);
+
+    %ANSILevel = (
+		'ERR'       => colored(['white on_red'],       '[ ERROR ]'),
+		'WARN'      => colored(['black on_yellow'],    '[WARNING]'),
+		'NOTICE'    => colored(['black on_magenta'],   '[NOTICE ]'),
+		'INFO'      => colored(['white on_black'],     '[ INFO  ]'),
+		'DEBUG'     => colored(['bold green on_black'],'[ DEBUG ]'),
+		'DEBUGMAX'  => colored(['bold green on_black'],'[-DEBUG-]')
+    );
+    # This assembles the Time and Date stamping output.  If any of the
+    # variables are blank, then that part will be disabled.
+    $self->{'PREFIX'} = $self->{'DATESTAMP'} . ' ' . $self->{'TIMESTAMP'};
+
+    # The Global loglevel is set here.
+    if ($self->{'LOGLEVEL'} eq 'VERBOSE') {
+		$self->{'LOG'}->level('INFO');
+    } elsif ($self->{'LOGLEVEL'} eq 'DEBUGMAX') {
+		$self->{'LOG'}->level('DEBUG');
+    } else {
+		$self->{'LOG'}->level( $self->{'LOGLEVEL'} );
+    }
+
+    $self->{'LOG'}->config({
+							   'type'   => $self->{'TYPE'},
+							   'path'   => $self->{'PATH'},
+							   'prefix' => $self->{'PREFIX'},
+							   'fh'     => $self->{'FILEHANDLE'}
+						   });
+    $self->{'LOG'}->DEBUG('   %.02f%s %s',0,$ANSILevel{'DEBUG'}, colored(['black on_white'],'----- Script begin -----'));
+    bless($self,$class);
+    return($self);
+}
+
+=head2 debug
+
+The parameters must be passed in the order given
+
+=over 1
+
+=item B<LINE>
+
+ The line number with which the debug was called.  Typically '__LINE__'
+
+=item B<LEVEL>
+
+ The log level with which this message is to be triggered
+
+=item B<MESSAGE(S)>
+
+ A string or list of strings to output line by line.
+
+=back
+
+=cut
+
+sub debug {
+    my $self  = shift;
+    my $cline = shift;
+    my $level = shift;
+    my $msgs  = shift;
+
+    my @messages;
+
+    if (ref($msgs) eq 'SCALAR') {
+		push(@messages,$msgs);
+    } elsif (ref($msgs) eq 'ARRAY') {
+		@messages = @{$msgs};
+    } else {
+		push(@messages,Dumper($msgs));
+    }
+
+    my ($package, $filename, $line, $subroutine, $hasargs, $wantarray, $evaltext, $is_require, $hints, $bitmask) = caller(1);
+    if (! defined($subroutine) || $subroutine eq '') {
+		$subroutine = 'main';
+    }
+    if (length($subroutine) > abs($self->{'PADDING'})) {
+		$self->{'PADDING'} = 0 - length($subroutine);
+    }
+    my $thisBench  = sprintf('%7s',sprintf(' %.02f',time - $self->{$level . '_LASTSTAMP'})) . $ANSILevel{$level} . '[' . colored(['bold cyan on_black'],sprintf('%' . $self->{'PADDING'} . 's>%04d',$subroutine,$cline)) . ']';
+    my $thisBench2 = ' ' x 7 . $ANSILevel{$level} . '[' . colored(['bold cyan on_black'],sprintf('%' . $self->{'PADDING'} . 's>%04d',$subroutine,$cline)) . ']';
+    my $nested = do { my $n=0; 1 while caller(2 + $n++); ' ' x $n };
+	my $first = 1;
+    foreach my $msg (@messages) {
+		if ($msg =~ /\n/s) {
+			my @message = split(/\n/,$msg);
+			foreach my $line (@message) {
+				if ($level eq 'INFO' && $self->{'LOGLEVEL'} eq 'VERBOSE') {
+					$self->{'LOG'}->config({'prefix' => ''});
+					$self->{'LOG'}->$level($line);
+					$self->{'LOG'}->config({'prefix' => $self->{'PREFIX'}});
+				} elsif ($level eq 'DEBUGMAX') {
+					if ($self->{'LOGLEVEL'} eq 'DEBUGMAX') {
+						if ($first) {
+							$self->{'LOG'}->DEBUG($thisBench . $nested . $line);
+						} else {
+							$self->{'LOG'}->DEBUG($thisBench2 . $nested . $line);
+						}
+					}
+				} else {
+					if ($first) {
+						$self->{'LOG'}->$level($thisBench . $nested . $line);
+					} else {
+						$self->{'LOG'}->$level($thisBench2 . $nested . $line);
+					}
+				}
+			}
+		} else {
+			if ($level eq 'INFO' && $self->{'LOGLEVEL'} eq 'VERBOSE') {
+				$self->{'LOG'}->config({'prefix' => ''});
+				$self->{'LOG'}->INFO($msg);
+				$self->{'LOG'}->config({'prefix' => $self->{'PREFIX'}});
+			} elsif ($level eq 'DEBUGMAX') {
+				if ($self->{'LOGLEVEL'} eq 'DEBUGMAX') {
+					$self->{'LOG'}->DEBUG($thisBench . $nested . $msg);
+				}
+			} else {
+				$self->{'LOG'}->$level($thisBench . $nested . $msg);
+			}
+		}
+    }
+    $self->{$level . '_LASTSTAMP'} = time;
+}
 
 =head1 AUTHOR
 
@@ -404,6 +457,8 @@ L<http://search.cpan.org/dist/Debug-Easy/>
 
 =head1 ACKNOWLEDGEMENTS
 
+The author of Log::Fast.  A very fine module, without which, this module
+would be much larger.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -447,4 +502,8 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
+
 1;
+
+__END__
+
